==> sri_d3m-1.6.0-py3-none-any.whl: sri/pipelines/edgelist_to_graph_vertex_classification.py <==
from d3m.metadata import base as meta_base
from d3m.metadata import pipeline as meta_pipeline

from sri.pipelines.base import BasePipeline
from sri.graph.edgelist_to_graph import EdgeListToGraph
from sri.graph.graph_to_edgelist import GraphToEdgeList
from sri.graph.vertex_classification import VertexClassificationParser

DATASETS = {
    'LL1_EDGELIST_net_nomination_seed',
    'LL1_VTXC_1343_cora',
    'LL1_VTXC_1369_synthetic',
    'LL1_net_classification_seed',
}

class EdgeListToGraphVertexClassificationPipeline(BasePipeline):
    def __init__(self):
        super().__init__(DATASETS, False)

    def _gen_pipeline(self):
        pipeline = meta_pipeline.Pipeline()
        pipeline.add_input(name = 'inputs')

        step_0 = meta_pipeline.PrimitiveStep(primitive_description = VertexClassificationParser.metadata.query())
        step_0.add_argument(
                name = 'inputs',
                argument_type = meta_base.ArgumentType.CONTAINER,
                data_reference = 'inputs.0'
        )
        step_0.add_output('produce')
        pipeline.add_step(step_0)

        step_1 = meta_pipeline.PrimitiveStep(primitive_description = GraphToEdgeList.metadata.query())
        step_1.add_argument(
                name = 'inputs',
                argument_type = meta_base.ArgumentType.CONTAINER,
                data_reference = 'steps.0.produce'
        )
        step_1.add_output('produce')
        pipeline.add_step(step_1)

        step_2 = meta_pipeline.PrimitiveStep(primitive_description = EdgeListToGraph.metadata.query())
        step_2.add_argument(
                name = 'inputs',
                argument_type = meta_base.ArgumentType.CONTAINER,
                data_reference = 'steps.1.produce'
        )
        step_2.add_output('produce')
        pipeline.add_step(step_2)

        # Adding output step to the pipeline
        pipeline.add_output(name = 'Graphs', data_reference = 'steps.2.produce')

        return pipeline

==> sri_d3m-1.8.9-py3-none-any.whl: sri/pipelines/edgelist_to_graph_vertex_classification.py <==
from d3m.metadata import base as meta_base
from d3m.metadata import pipeline as meta_pipeline

from sri.pipelines.base import BasePipeline
from sri.graph.edgelist_to_graph import EdgeListToGraph
from sri.graph.graph_to_edgelist import GraphToEdgeList
from sri.graph.vertex_classification import VertexClassificationParser

#TODO: Add back the other problem types when they are ported over
DATASETS = {
    # 'LL1_EDGELIST_net_nomination_seed',
    # 'LL1_VTXC_1343_cora',
    # 'LL1_VTXC_1369_synthetic',
    # 'LL1_net_classification_seed',
    'LL1_VTXC_1369_synthetic_MIN_METADATA',
}

class EdgeListToGraphVertexClassificationPipeline(BasePipeline):
    def __init__(self):
        super().__init__(DATASETS, False)

    def _gen_pipeline(self):
        pipeline = meta_pipeline.Pipeline()
        pipeline.add_input(name = 'inputs')

        step_0 = meta_pipeline.PrimitiveStep(primitive_description = VertexClassificationParser.metadata.query())
        step_0.add_argument(
                name = 'inputs',
                argument_type = meta_base.ArgumentType.CONTAINER,
                data_reference = 'inputs.0'
        )
        step_0.add_output('produce')
        pipeline.add_step(step_0)

        step_1 = meta_pipeline.PrimitiveStep(primitive_description = GraphToEdgeList.metadata.query())
        step_1.add_argument(
                name = 'inputs',
                argument_type = meta_base.ArgumentType.CONTAINER,
                data_reference = 'steps.0.produce'
        )
        step_1.add_output('produce')
        pipeline.add_step(step_1)

        step_2 = meta_pipeline.PrimitiveStep(primitive_description = EdgeListToGraph.metadata.query())
        step_2.add_argument(
                name = 'inputs',
                argument_type = meta_base.ArgumentType.CONTAINER,
                data_reference = 'steps.1.produce'
        )
        step_2.add_output('produce')
        pipeline.add_step(step_2)

        # Adding output step to the pipeline
        pipeline.add_output(name = 'Graphs', data_reference = 'steps.2.produce')

        return pipeline
